@@ -4,16 +4,10 @@
  * Module dependencies.
  */
 
-var Agent = require('superagent').agent;
-var methods = require('methods');
-var http = require('http');
-var Test = require('./test');
-
-/**
- * Expose `Agent`.
- */
-
-module.exports = TestAgent;
+const { agent: Agent } = require('superagent');
+const methods = require('methods');
+const http = require('http');
+const Test = require('./test.js');
 
 /**
  * Initialize a new `TestAgent`.
@@ -50,7 +44,7 @@ TestAgent.prototype.host = function(host) {
 // override HTTP verb methods
 methods.forEach(function(method) {
   TestAgent.prototype[method] = function(url, fn) { // eslint-disable-line no-unused-vars
-    var req = new Test(this.app, method.toUpperCase(), url, this._host);
+    const req = new Test(this.app, method.toUpperCase(), url, this._host);
     req.ca(this._ca);
     req.cert(this._cert);
     req.key(this._key);
@@ -69,3 +63,9 @@ methods.forEach(function(method) {
 });
 
 TestAgent.prototype.del = TestAgent.prototype.delete;
+
+/**
+ * Expose `Agent`.
+ */
+
+module.exports = TestAgent;
