@@ -1,6 +1,5 @@
 'use strict';
 
-const request = require('..');
 const https = require('https');
 const fs = require('fs');
 const path = require('path');
@@ -9,6 +8,7 @@ const express = require('express');
 const bodyParser = require('body-parser');
 const cookieParser = require('cookie-parser');
 const nock = require('nock');
+const request = require('../index.js');
 
 process.env.NODE_TLS_REJECT_UNAUTHORIZED = '0';
 
@@ -399,6 +399,38 @@ describe('request(app)', function () {
     });
   });
 
+  describe('.expect(statusArray)', function () {
+    it('should assert only status', function (done) {
+      const app = express();
+
+      app.get('/', function (req, res) {
+        res.send('hey');
+      });
+
+      request(app)
+        .get('/')
+        .expect([200, 404])
+        .end(done);
+    });
+
+    it('should reject if status is not in valid statuses array', function (done) {
+      const app = express();
+
+      app.get('/', function (req, res) {
+        res.send('hey');
+      });
+
+      request(app)
+        .get('/')
+        .expect([500, 404])
+        .end(function (err, res) {
+          err.message.should.equal('expected one of "500, 404", got 200 "OK"');
+          shouldIncludeStackWithThisFile(err);
+          done();
+        });
+    });
+  });
+
   describe('.expect(status, body[, fn])', function () {
     it('should assert the response body and status', function (done) {
       const app = express();
@@ -541,6 +573,28 @@ describe('request(app)', function () {
         });
     });
 
+    it('should support parsed response arrays', function (done) {
+      const app = express();
+      app.get('/', function (req, res) {
+        res.status(200).json(['a', { id: 1 }]);
+      });
+
+      request(app)
+        .get('/')
+        .expect(['a', { id: 1 }], done);
+    });
+
+    it('should support empty array responses', function (done) {
+      const app = express();
+      app.get('/', function (req, res) {
+        res.status(200).json([]);
+      });
+
+      request(app)
+        .get('/')
+        .expect([], done);
+    });
+
     it('should support regular expressions', function (done) {
       const app = express();
 
